Database directory
==================

The result of the ACQDIV ETL pipeline (the SQLite database file) is written to this directory. The script `sqlite_to_r.R` can be run to convert the SQLite tables into R dataframes in a serialized R data object.
